==> dataiku-dss-14.2.2.tar.gz: dataiku-dss-14.2.2/frontend/static/dataiku/js/dashboards/controllers/dashboard-page-right-column-actions.controller.js <==
(function() {
    'use strict';

    const app = angular.module('dataiku.dashboards');

    /**
     * Was previously located here: src/main/platypus/static/dataiku/js/dashboards/core.js
     */
    app.controller('DashboardPageRightColumnActions', async function($controller, $scope, $rootScope, $stateParams, DataikuAPI, ActiveProjectKey) {

        $controller('_TaggableObjectPageRightColumnActions', { $scope: $scope });

        const dashboard = (await DataikuAPI.dashboards.get($stateParams.projectKey, $stateParams.dashboardId)).data;
        dashboard.nodeType = 'DASHBOARD';
        dashboard.interest = {};

        $scope.selection = {
            selectedObject: dashboard,
            confirmedItem: dashboard
        };

        $scope.renameObjectAndSave = function(newName) {
            $scope.dashboard.name = newName;
            return DataikuAPI.dashboards.save($scope.dashboard);
        };

        function updateListed() {
            DataikuAPI.dashboards.get($stateParams.projectKey, $stateParams.dashboardId).success(function(data) {

                $scope.selection.selectedObject.listed = data.listed;

            }).error(setErrorInScope.bind($scope));
        }

        function updateUserInterests() {
            DataikuAPI.interests.getForObject($rootScope.appConfig.login, 'DASHBOARD', ActiveProjectKey.get(), $stateParams.dashboardId).success(function(data) {

                $scope.selection.selectedObject.interest = data;
                $scope.dashboardFullInfo.interest = data;

            }).error(setErrorInScope.bind($scope));
        }

        updateUserInterests();
        const interestsListener = $rootScope.$on('userInterestsUpdated', updateUserInterests);
        const listedListener = $scope.$on('objectTimelineChanged', updateListed);
        $scope.$on('$destroy', interestsListener);
        $scope.$on('$destroy', listedListener);
    });

})();

==> dataiku-dss-14.4.0.tar.gz: dataiku-dss-14.4.0/frontend/static/dataiku/js/dashboards/controllers/dashboard-page-right-column-actions.controller.js <==
(function() {
    'use strict';

    const app = angular.module('dataiku.dashboards');

    /**
     * Was previously located here: src/main/platypus/static/dataiku/js/dashboards/core.js
     */
    app.controller('DashboardPageRightColumnActions', async function($controller, $scope, $rootScope, $stateParams, DataikuAPI, ActiveProjectKey) {

        $controller('_TaggableObjectPageRightColumnActions', { $scope: $scope });

        const dashboard = (await DataikuAPI.dashboards.get($stateParams.projectKey, $stateParams.dashboardId, $stateParams.exportId)).data;
        dashboard.nodeType = 'DASHBOARD';
        dashboard.interest = {};

        $scope.selection = {
            selectedObject: dashboard,
            confirmedItem: dashboard
        };

        $scope.renameObjectAndSave = function(newName) {
            $scope.dashboard.name = newName;
            return DataikuAPI.dashboards.save($scope.dashboard);
        };

        function updateUserInterests() {
            DataikuAPI.interests.getForObject($rootScope.appConfig.login, 'DASHBOARD', ActiveProjectKey.get(), $stateParams.dashboardId).success(function(data) {

                $scope.selection.selectedObject.interest = data;
                $scope.dashboardFullInfo.interest = data;

            }).error(setErrorInScope.bind($scope));
        }

        updateUserInterests();
        const interestsListener = $rootScope.$on('userInterestsUpdated', updateUserInterests);
        $scope.$on('$destroy', interestsListener);
    });

})();
